@@ -3,14 +3,16 @@
 # This sub-module is destined for common non-package specific utility
 # functions.
 
-import warnings
-
 import numpy as np
 from numba import njit
 
 from .. import units as u
 from .data import RemoteData  # noqa: F401
 
+import logging
+
+log = logging.getLogger("pysm3")
+
 
 def has_polarization(m):
     """Checks if a map or a group of map is polarized
@@ -111,7 +113,7 @@ def bandpass_unit_conversion(
         weights /= np.trapz(weights, freqs)
         if weights.min() < cut:
             good = np.logical_not(weights < cut)
-            warnings.warn(
+            log.info(
                 "Removing {}/{} points below {}".format(good.sum(), len(good), cut)
             )
             weights = weights[good]
@@ -159,7 +161,7 @@ def trapz_step_inplace(freqs, weights, i, m, output):
 
 
 def check_freq_input(freqs):
-    """ Function to check that the input to `Model.get_emission` is a
+    """Function to check that the input to `Model.get_emission` is a
     np.ndarray.
 
     This function will convert input scalar frequencies
